@@ -101,7 +101,7 @@ private:
 };
 
 PdfVecObjects::PdfVecObjects()
-    : m_bAutoDelete( false ), m_nObjectCount( 1 ), m_bSorted( true ), m_pDocument( NULL ), m_pStreamFactory( NULL )
+    : m_bAutoDelete( false ), m_bCanReuseObjectNumbers( true ), m_nObjectCount( 1 ), m_bSorted( true ), m_pDocument( NULL ), m_pStreamFactory( NULL )
 {
 }
 
@@ -149,17 +149,11 @@ PdfObject* PdfVecObjects::GetObject( const PdfReference & ref ) const
         const_cast<PdfVecObjects*>(this)->Sort();
 
     PdfObject refObj( ref, NULL );
-    std::pair<TCIVecObjects,TCIVecObjects> it = 
-        std::equal_range( m_vector.begin(), m_vector.end(), &refObj, ObjectComparatorPredicate() );
-
-    if( it.first != it.second )
-        return *(it.first);
-
-    /*
-    const TCIVecObjects it ( std::find_if( this->begin(), this->end(), ObjectsComparator( ref ) ) );
-    if( it != this->end() )
-        return (*it);
-    */
+    TCIVecObjects it = std::lower_bound( m_vector.begin(), m_vector.end(), &refObj, ObjectComparatorPredicate() );
+    if( it != m_vector.end() && (refObj.Reference() == (*it)->Reference()) )
+    {
+        return *it;
+    }
 
     return NULL;
 }
@@ -225,7 +219,7 @@ PdfReference PdfVecObjects::GetNextFreeObject()
 {
     PdfReference ref( static_cast<unsigned int>(m_nObjectCount), 0 );
 
-    if( !m_lstFreeObjects.empty() )
+    if( m_bCanReuseObjectNumbers && !m_lstFreeObjects.empty() )
     {
         ref = m_lstFreeObjects.front();
         m_lstFreeObjects.pop_front();
@@ -264,7 +258,7 @@ void PdfVecObjects::AddFreeObject( const PdfReference & rReference )
     if( it.first != it.second && !m_lstFreeObjects.empty() ) 
     {
         // Be sure that no reference is added twice to free list
-        PdfError::DebugMessage( "Adding %d to freelist, is already contained !!", rReference.ObjectNumber() );
+        PdfError::DebugMessage( "Adding %d to free list, is already contained in it!", rReference.ObjectNumber() );
         return;
     }
     else
@@ -607,6 +601,16 @@ std::string PdfVecObjects::GetNextSubsetPrefix()
 	return m_sSubsetPrefix;
 }
 
+void PdfVecObjects::SetCanReuseObjectNumbers( bool bCanReuseObjectNumbers )
+{
+    m_bCanReuseObjectNumbers = bCanReuseObjectNumbers;
+
+    if( !m_bCanReuseObjectNumbers )
+    {
+        m_lstFreeObjects.clear();
+    }
+}
+
 };
 
 
